@@ -1,18 +1,14 @@
 from PySide6.QtCore import QThread, Signal
+from .utils.Serializable import Serializable, SerializableCallable
 
 class QWorker(QThread):
-    from PyQWebWindow.controllers.BindingController import Serializable, SerializableCallable
-
     finished = Signal(type(Serializable))
 
     def __init__(self, task: SerializableCallable):
         super().__init__(None)
         self._task = task
+        self._args = None
 
-    @property
-    def name(self):
-        return self._task.__name__
-    
     def set_args(self, args: list[Serializable]):
         self._args = args
 
