@@ -1,3 +1,5 @@
+from typing import Callable, Union, TypeAlias
 from .WebViewController import WebViewController
 from .BindingController import BindingController
 from .WindowController import WindowController
+from ..ipc.QIpc import QIpcClient, QIpcServer
