@@ -9,15 +9,20 @@ for (const methodName of globalThis.backend._methods) {
 }
 """
 
-INITIALIZE_WORKERS = """\
-for (const workerName of globalThis.backend._workers) {
-    globalThis.backend[workerName] = (...args) => new Promise((resolve, _) => {
-        const callback = (result) => {
-            globalThis.backend._worker_finished.disconnect(callback)
-            resolve(result)
-        }
-        globalThis.backend._worker_finished.connect(callback)
-        globalThis.backend._start_worker(workerName, args)
+INITIALIZE_TASKS = """\
+const callbackNameFactory = () => crypto.randomUUID()
+const callbackMap = new Map()
+globalThis.backend._task_finished.connect((callbackName, result) => {
+    const callback = callbackMap.get(callbackName)
+    if (!callback) return
+    callback(result)
+    callbackMap.delete(callbackName)
+})
+for (const taskName of globalThis.backend._tasks) {
+    globalThis.backend[taskName] = (...args) => new Promise((resolve, _) => {
+        const callbackName = callbackNameFactory()
+        callbackMap.set(callbackName, resolve)
+        globalThis.backend._start_task(taskName, callbackName, args)
     })
 }
 """
@@ -29,7 +34,7 @@ script.onload = () => {{
     new QWebChannel(qt.webChannelTransport, (channel) => {{
         globalThis.backend = channel.objects.backend
         {INITIALIZE_METHODS}
-        {INITIALIZE_WORKERS}
+        {INITIALIZE_TASKS}
         globalThis.backendloaded = true
         globalThis.dispatchEvent(new CustomEvent('backendloaded'))
     }})
